Module: Google::Apis::HomegraphV1
- Defined in:
- lib/google/apis/homegraph_v1.rb,
lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/service.rb,
lib/google/apis/homegraph_v1/gem_version.rb,
lib/google/apis/homegraph_v1/representations.rb
Overview
HomeGraph API
Defined Under Namespace
Classes: AgentDeviceId, AgentOtherDeviceId, CameraEventStreamTrait, CommonEventDataStruct, Component, ComponentTraitUpdates, Device, DeviceBlameStruct, DeviceInfo, DeviceMetadata, DeviceNames, Empty, EveUtilityTrait, EventData, Events, HomeEvents, HomeGraphServiceService, HomeTraitPayload, HomeTraitUpdates, MediaUrlsStruct, MotionEvent, PartnerPresenceSignalTrait, PersonEvent, QueryRequest, QueryRequestInput, QueryRequestPayload, QueryResponse, QueryResponsePayload, ReportStateAndNotificationDevice, ReportStateAndNotificationRequest, ReportStateAndNotificationResponse, RequestSyncDevicesRequest, RequestSyncDevicesResponse, Result, StateAndNotificationPayload, StructurePresenceStateChangeEvent, StructurePresenceStateChangeReasonStruct, SyncRequest, SyncResponse, SyncResponsePayload, ThermostatFanControlTrait, TraitData, UserBlameStruct, ZoneStruct
Constant Summary collapse
- GEM_VERSION =
Version of the google-apis-homegraph_v1 gem
"0.33.0"- GENERATOR_VERSION =
Version of the code generator used to generate this client
"0.19.0"- REVISION =
Revision of the discovery document this client was generated from
"20260731"- VERSION =
Version of the HomeGraph API this client connects to. This is NOT the gem version.
'V1'- AUTH_HOMEGRAPH =
Private Service: https://www.googleapis.com/auth/homegraph
'https://www.googleapis.com/auth/homegraph'