Class: Google::Apis::HomegraphV1::Events

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb

Overview

Contains a set of events for a specific component.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Events

Returns a new instance of Events.



329
330
331
# File 'lib/google/apis/homegraph_v1/classes.rb', line 329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#component_idString

Optional. The ID of the provider component if the events are associated with a specific component. Optional for WHDM events, required for UDDM events. Corresponds to the JSON property componentId

Returns:

  • (String)


322
323
324
# File 'lib/google/apis/homegraph_v1/classes.rb', line 322

def component_id
  @component_id
end

#eventsArray<Google::Apis::HomegraphV1::EventData>

Required. List of events associated with the component. Corresponds to the JSON property events



327
328
329
# File 'lib/google/apis/homegraph_v1/classes.rb', line 327

def events
  @events
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



334
335
336
337
# File 'lib/google/apis/homegraph_v1/classes.rb', line 334

def update!(**args)
  @component_id = args[:component_id] if args.key?(:component_id)
  @events = args[:events] if args.key?(:events)
end