Class: Google::Apis::HomegraphV1::HomeGraphServiceService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::HomegraphV1::HomeGraphServiceService
- Defined in:
- lib/google/apis/homegraph_v1/service.rb
Overview
HomeGraph API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://homegraph.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#delete_agent_user(agent_user_id, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::Empty
Unlinks the given third-party user from your smart home Action.
-
#initialize ⇒ HomeGraphServiceService
constructor
A new instance of HomeGraphServiceService.
-
#query_device(query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::QueryResponse
Gets the current states in Home Graph for the given set of the third-party user's devices.
-
#report_device_state_and_notification(report_state_and_notification_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::ReportStateAndNotificationResponse
Reports device state and optionally sends device notifications.
-
#request_sync_devices(request_sync_devices_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::RequestSyncDevicesResponse
Requests Google to send an
action.devices.SYNCintent to your smart home Action to update device metadata for the given user. -
#sync_device(sync_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::SyncResponse
Gets all the devices associated with the given third-party user.
Constructor Details
#initialize ⇒ HomeGraphServiceService
Returns a new instance of HomeGraphServiceService.
47 48 49 50 51 52 |
# File 'lib/google/apis/homegraph_v1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-homegraph_v1', client_version: Google::Apis::HomegraphV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/homegraph_v1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/homegraph_v1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#delete_agent_user(agent_user_id, request_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::Empty
Unlinks the given third-party user from your smart home Action. All data
related to this user will be deleted. For more details on how users link their
accounts, see fulfillment and authentication. The third-party user's identity is
passed in via the agent_user_id (see DeleteAgentUserRequest). This request
must be authorized using service account credentials from your Actions console
project.
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/google/apis/homegraph_v1/service.rb', line 82 def delete_agent_user(agent_user_id, request_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/{+agentUserId}', ) command.response_representation = Google::Apis::HomegraphV1::Empty::Representation command.response_class = Google::Apis::HomegraphV1::Empty command.params['agentUserId'] = agent_user_id unless agent_user_id.nil? command.query['requestId'] = request_id unless request_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#query_device(query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::QueryResponse
Gets the current states in Home Graph for the given set of the third-party
user's devices. The third-party user's identity is passed in via the
agent_user_id (see QueryRequest). This request must be authorized using
service account credentials from your Actions console project.
115 116 117 118 119 120 121 122 123 124 |
# File 'lib/google/apis/homegraph_v1/service.rb', line 115 def query_device(query_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/devices:query', ) command.request_representation = Google::Apis::HomegraphV1::QueryRequest::Representation command.request_object = query_request_object command.response_representation = Google::Apis::HomegraphV1::QueryResponse::Representation command.response_class = Google::Apis::HomegraphV1::QueryResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#report_device_state_and_notification(report_state_and_notification_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::ReportStateAndNotificationResponse
Reports device state and optionally sends device notifications. Called by your
smart home Action when the state of a third-party device changes or you need
to send a notification about the device. See Implement Report State for more
information. This method updates the device state according to its declared
traits. Publishing a new state value outside of these traits will result
in an INVALID_ARGUMENT error response. The third-party user's identity is
passed in via the agent_user_id (see ReportStateAndNotificationRequest).
This request must be authorized using service account credentials from your
Actions console project.
155 156 157 158 159 160 161 162 163 164 |
# File 'lib/google/apis/homegraph_v1/service.rb', line 155 def report_device_state_and_notification(report_state_and_notification_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/devices:reportStateAndNotification', ) command.request_representation = Google::Apis::HomegraphV1::ReportStateAndNotificationRequest::Representation command.request_object = report_state_and_notification_request_object command.response_representation = Google::Apis::HomegraphV1::ReportStateAndNotificationResponse::Representation command.response_class = Google::Apis::HomegraphV1::ReportStateAndNotificationResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#request_sync_devices(request_sync_devices_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::RequestSyncDevicesResponse
Requests Google to send an action.devices.SYNC intent to your smart home Action to
update device metadata for the given user. The third-party user's identity is
passed via the agent_user_id (see RequestSyncDevicesRequest). This request
must be authorized using service account credentials from your Actions console
project.
190 191 192 193 194 195 196 197 198 199 |
# File 'lib/google/apis/homegraph_v1/service.rb', line 190 def request_sync_devices(request_sync_devices_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/devices:requestSync', ) command.request_representation = Google::Apis::HomegraphV1::RequestSyncDevicesRequest::Representation command.request_object = request_sync_devices_request_object command.response_representation = Google::Apis::HomegraphV1::RequestSyncDevicesResponse::Representation command.response_class = Google::Apis::HomegraphV1::RequestSyncDevicesResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#sync_device(sync_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::HomegraphV1::SyncResponse
Gets all the devices associated with the given third-party user. The third-
party user's identity is passed in via the agent_user_id (see SyncRequest).
This request must be authorized using service account credentials from your
Actions console project.
223 224 225 226 227 228 229 230 231 232 |
# File 'lib/google/apis/homegraph_v1/service.rb', line 223 def sync_device(sync_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/devices:sync', ) command.request_representation = Google::Apis::HomegraphV1::SyncRequest::Representation command.request_object = sync_request_object command.response_representation = Google::Apis::HomegraphV1::SyncResponse::Representation command.response_class = Google::Apis::HomegraphV1::SyncResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |