Class: Google::Apis::HomegraphV1::QueryRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb

Overview

Request type for the Query call.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QueryRequest

Returns a new instance of QueryRequest.



845
846
847
# File 'lib/google/apis/homegraph_v1/classes.rb', line 845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#agent_user_idString

Required. Third-party user ID. Corresponds to the JSON property agentUserId

Returns:

  • (String)


817
818
819
# File 'lib/google/apis/homegraph_v1/classes.rb', line 817

def agent_user_id
  @agent_user_id
end

#device_viewString

Optional. Specifies the type of device data to be returned in the response. This allows callers to request traditional Smart Home traits, Unified Device Data Model (UDDM) traits, or both. If unspecified, defaults to SMART_HOME_TRAIT_ONLY. Corresponds to the JSON property deviceView

Returns:

  • (String)


825
826
827
# File 'lib/google/apis/homegraph_v1/classes.rb', line 825

def device_view
  @device_view
end

#include_device_metadataBoolean Also known as: include_device_metadata?

Optional. If true, the response will include device metadata in the device_metadata field. Corresponds to the JSON property includeDeviceMetadata

Returns:

  • (Boolean)


831
832
833
# File 'lib/google/apis/homegraph_v1/classes.rb', line 831

def 
  @include_device_metadata
end

#inputsArray<Google::Apis::HomegraphV1::QueryRequestInput>

Required. Inputs containing third-party device IDs for which to get the device states. Corresponds to the JSON property inputs



838
839
840
# File 'lib/google/apis/homegraph_v1/classes.rb', line 838

def inputs
  @inputs
end

#request_idString

Request ID used for debugging. Corresponds to the JSON property requestId

Returns:

  • (String)


843
844
845
# File 'lib/google/apis/homegraph_v1/classes.rb', line 843

def request_id
  @request_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



850
851
852
853
854
855
856
# File 'lib/google/apis/homegraph_v1/classes.rb', line 850

def update!(**args)
  @agent_user_id = args[:agent_user_id] if args.key?(:agent_user_id)
  @device_view = args[:device_view] if args.key?(:device_view)
  @include_device_metadata = args[:include_device_metadata] if args.key?(:include_device_metadata)
  @inputs = args[:inputs] if args.key?(:inputs)
  @request_id = args[:request_id] if args.key?(:request_id)
end