Class: Google::Apis::HomegraphV1::ReportStateAndNotificationResponse
- Inherits:
-
Object
- Object
- Google::Apis::HomegraphV1::ReportStateAndNotificationResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb
Overview
Response type for the ReportStateAndNotification call.
Instance Attribute Summary collapse
-
#device_results ⇒ Hash<String,Google::Apis::HomegraphV1::Result>
Map from agent device ID to the result of reporting state and notifications.
-
#request_id ⇒ String
Request ID copied from ReportStateAndNotificationRequest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportStateAndNotificationResponse
constructor
A new instance of ReportStateAndNotificationResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportStateAndNotificationResponse
Returns a new instance of ReportStateAndNotificationResponse.
1078 1079 1080 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_results ⇒ Hash<String,Google::Apis::HomegraphV1::Result>
Map from agent device ID to the result of reporting state and notifications.
This is only populated for UDDM updates for now.
Corresponds to the JSON property deviceResults
1071 1072 1073 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1071 def device_results @device_results end |
#request_id ⇒ String
Request ID copied from ReportStateAndNotificationRequest.
Corresponds to the JSON property requestId
1076 1077 1078 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1076 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1083 1084 1085 1086 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1083 def update!(**args) @device_results = args[:device_results] if args.key?(:device_results) @request_id = args[:request_id] if args.key?(:request_id) end |