Class: Google::Apis::HomegraphV1::Result

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb

Overview

Result of reporting state and notifications for a single device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Result

Returns a new instance of Result.



1142
1143
1144
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#home_trait_commit_timeString

The trait commit timestamp of the state update in Home Graph. Corresponds to the JSON property homeTraitCommitTime

Returns:

  • (String)


1140
1141
1142
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1140

def home_trait_commit_time
  @home_trait_commit_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1147
1148
1149
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1147

def update!(**args)
  @home_trait_commit_time = args[:home_trait_commit_time] if args.key?(:home_trait_commit_time)
end