Class: Google::Apis::HomegraphV1::StructurePresenceStateChangeEvent
- Inherits:
-
Object
- Object
- Google::Apis::HomegraphV1::StructurePresenceStateChangeEvent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb
Overview
Sent when the structure presence state changes.
Instance Attribute Summary collapse
-
#presence_state ⇒ String
Required.
-
#reason ⇒ Google::Apis::HomegraphV1::StructurePresenceStateChangeReasonStruct
Contains the metadata about the cause of the structure presence state change.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StructurePresenceStateChangeEvent
constructor
A new instance of StructurePresenceStateChangeEvent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StructurePresenceStateChangeEvent
Returns a new instance of StructurePresenceStateChangeEvent.
1185 1186 1187 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#presence_state ⇒ String
Required. Specifies the presence state.
Corresponds to the JSON property presenceState
1178 1179 1180 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1178 def presence_state @presence_state end |
#reason ⇒ Google::Apis::HomegraphV1::StructurePresenceStateChangeReasonStruct
Contains the metadata about the cause of the structure presence state change.
Corresponds to the JSON property reason
1183 1184 1185 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1183 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1190 1191 1192 1193 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1190 def update!(**args) @presence_state = args[:presence_state] if args.key?(:presence_state) @reason = args[:reason] if args.key?(:reason) end |