Class: Google::Apis::HomegraphV1::StructurePresenceStateChangeReasonStruct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb

Overview

Contains the metadata about the cause of the structure presence state change.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StructurePresenceStateChangeReasonStruct

Returns a new instance of StructurePresenceStateChangeReasonStruct.



1212
1213
1214
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1212

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#device_blameGoogle::Apis::HomegraphV1::DeviceBlameStruct

Contains metadata about the cause of presence state change attributed to a device. Corresponds to the JSON property deviceBlame



1204
1205
1206
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1204

def device_blame
  @device_blame
end

#user_blameGoogle::Apis::HomegraphV1::UserBlameStruct

Contains metadata about the cause of presence state change attributed to a user. Corresponds to the JSON property userBlame



1210
1211
1212
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1210

def user_blame
  @user_blame
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1217
1218
1219
1220
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1217

def update!(**args)
  @device_blame = args[:device_blame] if args.key?(:device_blame)
  @user_blame = args[:user_blame] if args.key?(:user_blame)
end