Class: Google::Apis::HomegraphV1::CommonEventDataStruct
- Inherits:
-
Object
- Object
- Google::Apis::HomegraphV1::CommonEventDataStruct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb
Overview
Common camera event data.
Instance Attribute Summary collapse
-
#media_urls ⇒ Google::Apis::HomegraphV1::MediaUrlsStruct
Contains media urls for the event Corresponds to the JSON property
mediaUrls. -
#session_id ⇒ String
Camera event session id.
-
#track_id ⇒ String
Id of the track this object belongs to Corresponds to the JSON property
trackId.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommonEventDataStruct
constructor
A new instance of CommonEventDataStruct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommonEventDataStruct
Returns a new instance of CommonEventDataStruct.
102 103 104 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#media_urls ⇒ Google::Apis::HomegraphV1::MediaUrlsStruct
Contains media urls for the event
Corresponds to the JSON property mediaUrls
90 91 92 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 90 def media_urls @media_urls end |
#session_id ⇒ String
Camera event session id. Used for identifying a unique event session
Corresponds to the JSON property sessionId
95 96 97 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 95 def session_id @session_id end |
#track_id ⇒ String
Id of the track this object belongs to
Corresponds to the JSON property trackId
100 101 102 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 100 def track_id @track_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
107 108 109 110 111 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 107 def update!(**args) @media_urls = args[:media_urls] if args.key?(:media_urls) @session_id = args[:session_id] if args.key?(:session_id) @track_id = args[:track_id] if args.key?(:track_id) end |