Class: Google::Apis::HomegraphV1::DeviceNames

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb

Overview

Identifiers used to describe the device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeviceNames

Returns a new instance of DeviceNames.



315
316
317
# File 'lib/google/apis/homegraph_v1/classes.rb', line 315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_namesArray<String>

List of names provided by the manufacturer rather than the user, such as serial numbers, SKUs, etc. Corresponds to the JSON property defaultNames

Returns:

  • (Array<String>)


301
302
303
# File 'lib/google/apis/homegraph_v1/classes.rb', line 301

def default_names
  @default_names
end

#nameString

Primary name of the device, generally provided by the user. Names will be truncated if over the 60 Unicode code point (character) limit and no errors will be thrown. Developers are responsible for handling long names. Corresponds to the JSON property name

Returns:

  • (String)


308
309
310
# File 'lib/google/apis/homegraph_v1/classes.rb', line 308

def name
  @name
end

#nicknamesArray<String>

Additional names provided by the user for the device. Corresponds to the JSON property nicknames

Returns:

  • (Array<String>)


313
314
315
# File 'lib/google/apis/homegraph_v1/classes.rb', line 313

def nicknames
  @nicknames
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



320
321
322
323
324
# File 'lib/google/apis/homegraph_v1/classes.rb', line 320

def update!(**args)
  @default_names = args[:default_names] if args.key?(:default_names)
  @name = args[:name] if args.key?(:name)
  @nicknames = args[:nicknames] if args.key?(:nicknames)
end