Class: Google::Apis::HomegraphV1::MediaUrlsStruct
- Inherits:
-
Object
- Object
- Google::Apis::HomegraphV1::MediaUrlsStruct
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb
Instance Attribute Summary collapse
-
#dash_manifest_url ⇒ String
URL for a dash manifest for playback Corresponds to the JSON property
dashManifestUrl. -
#hls_master_playlist_url ⇒ String
URL for a hls master playlist for playback Corresponds to the JSON property
hlsMasterPlaylistUrl. -
#preview_url ⇒ String
URL for animated preview clip representing the event session Corresponds to the JSON property
previewUrl. -
#thumbnail_url ⇒ String
URL for thumbnail image representing the event session Corresponds to the JSON property
thumbnailUrl.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MediaUrlsStruct
constructor
A new instance of MediaUrlsStruct.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MediaUrlsStruct
Returns a new instance of MediaUrlsStruct.
718 719 720 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 718 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dash_manifest_url ⇒ String
URL for a dash manifest for playback
Corresponds to the JSON property dashManifestUrl
701 702 703 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 701 def dash_manifest_url @dash_manifest_url end |
#hls_master_playlist_url ⇒ String
URL for a hls master playlist for playback
Corresponds to the JSON property hlsMasterPlaylistUrl
706 707 708 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 706 def hls_master_playlist_url @hls_master_playlist_url end |
#preview_url ⇒ String
URL for animated preview clip representing the event session
Corresponds to the JSON property previewUrl
711 712 713 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 711 def preview_url @preview_url end |
#thumbnail_url ⇒ String
URL for thumbnail image representing the event session
Corresponds to the JSON property thumbnailUrl
716 717 718 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 716 def thumbnail_url @thumbnail_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
723 724 725 726 727 728 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 723 def update!(**args) @dash_manifest_url = args[:dash_manifest_url] if args.key?(:dash_manifest_url) @hls_master_playlist_url = args[:hls_master_playlist_url] if args.key?(:hls_master_playlist_url) @preview_url = args[:preview_url] if args.key?(:preview_url) @thumbnail_url = args[:thumbnail_url] if args.key?(:thumbnail_url) end |