Class: Google::Apis::HomegraphV1::ReportStateAndNotificationRequest
- Inherits:
-
Object
- Object
- Google::Apis::HomegraphV1::ReportStateAndNotificationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb
Overview
Request type for the ReportStateAndNotification call. It may include states,
notifications, or both. States and notifications are defined per device_id (
for example, "123" and "456" in the following example). Example: json ` "
requestId": "ff36a3cc-ec34-11e6-b1a0-64510650abcf", "agentUserId": "1234", "
payload": ` "devices": ` "states": ` "123": ` "on": true `, "456": ` "on":
true, "brightness": 10 `, `, ` ` `
Instance Attribute Summary collapse
-
#agent_user_id ⇒ String
Required.
-
#event_id ⇒ String
Unique identifier per event (for example, a doorbell press).
-
#follow_up_token ⇒ String
Deprecated.
-
#payload ⇒ Google::Apis::HomegraphV1::StateAndNotificationPayload
Payload containing the state and notification information for devices.
-
#request_id ⇒ String
Request ID used for debugging.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportStateAndNotificationRequest
constructor
A new instance of ReportStateAndNotificationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportStateAndNotificationRequest
Returns a new instance of ReportStateAndNotificationRequest.
587 588 589 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 587 def initialize(**args) update!(**args) end |
Instance Attribute Details
#agent_user_id ⇒ String
Required. Third-party user ID.
Corresponds to the JSON property agentUserId
565 566 567 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 565 def agent_user_id @agent_user_id end |
#event_id ⇒ String
Unique identifier per event (for example, a doorbell press).
Corresponds to the JSON property eventId
570 571 572 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 570 def event_id @event_id end |
#follow_up_token ⇒ String
Deprecated.
Corresponds to the JSON property followUpToken
575 576 577 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 575 def follow_up_token @follow_up_token end |
#payload ⇒ Google::Apis::HomegraphV1::StateAndNotificationPayload
Payload containing the state and notification information for devices.
Corresponds to the JSON property payload
580 581 582 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 580 def payload @payload end |
#request_id ⇒ String
Request ID used for debugging.
Corresponds to the JSON property requestId
585 586 587 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 585 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
592 593 594 595 596 597 598 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 592 def update!(**args) @agent_user_id = args[:agent_user_id] if args.key?(:agent_user_id) @event_id = args[:event_id] if args.key?(:event_id) @follow_up_token = args[:follow_up_token] if args.key?(:follow_up_token) @payload = args[:payload] if args.key?(:payload) @request_id = args[:request_id] if args.key?(:request_id) end |