Class: Google::Apis::HomegraphV1::Result
- Inherits:
-
Object
- Object
- Google::Apis::HomegraphV1::Result
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/homegraph_v1/classes.rb,
lib/google/apis/homegraph_v1/representations.rb,
lib/google/apis/homegraph_v1/representations.rb
Overview
Result of reporting state and notifications for a single device.
Instance Attribute Summary collapse
-
#home_trait_commit_time ⇒ String
The trait commit timestamp of the state update in Home Graph.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Result
constructor
A new instance of Result.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Result
Returns a new instance of Result.
1142 1143 1144 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#home_trait_commit_time ⇒ String
The trait commit timestamp of the state update in Home Graph.
Corresponds to the JSON property homeTraitCommitTime
1140 1141 1142 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1140 def home_trait_commit_time @home_trait_commit_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1147 1148 1149 |
# File 'lib/google/apis/homegraph_v1/classes.rb', line 1147 def update!(**args) @home_trait_commit_time = args[:home_trait_commit_time] if args.key?(:home_trait_commit_time) end |